from __future__ import absolute_import
from mobiko.template import default_template
from mobiko.conversion import scale
from PIL import Image
import os


def main():
    from argparse import ArgumentParser

    parser = ArgumentParser()
    parser.add_argument('file')
    args = parser.parse_args()

    filename = args.file
    dirname = os.path.dirname(filename)
    template = default_template
    basename = os.path.basename(filename)
    noextname = basename.split('.')[0]

    image = Image.open(filename)

    for t in template:
        size, scale = t
        absize = size * scale
        outfile = os.path.join(dirname, '{}-{}@{}x.png'\
                    .format(noextname, size, scale)
                  )

        img = image.resize((int(absize), int(absize)), Image.ANTIALIAS)
        img.save(outfile)


if __name__ == '__main__':
    main()


from __future__ import absolute_import
from os.path import join, dirname
from setuptools import setup
import mobiko

basepath = dirname(__file__)
binpath = join(basepath, 'bin')

setup(
  name = 'mobiko',
  packages = ['mobiko'],
  version = mobiko.__version__,
  description = 'Make images for iOS app icon from a big PNG',
  long_description = open(join(basepath, 'README.txt')).read(),
  scripts = [join(binpath, 'mobiko')],
  install_requires=[],
  author = 'Gamaliel Espinoza M.',
  author_email = 'gamaliel.espinoza@gmail.com',
  url = 'https://github.com/gamikun/mobiko',
  keywords = ['image', 'icons', ''],
  classifiers = [],
)
